no-unwanted-files
=================

Specific file types are allowed in certain directories:

- ``lib`` - All content must reside in the ``lib/ansible`` directory.

- ``lib/ansible`` - Only source code with one of the following extensions is allowed:

  - ``*.cs`` - C#
  - ``*.ps1`` - PowerShell
  - ``*.psm1`` - PowerShell
  - ``*.py`` - Python
